/*
 * Copyright 2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej.i18n;

import java.util.Locale;

import com.google.common.base.Supplier;

/**
 * Generic interface for localized objects.
 * @author Andres Rodriguez
 */
public interface Localized<T> extends Supplier<T> {
	/**
	 * Returns the default locale.
	 * @return The defautl locale.
	 */
	Locale getDefault();
	/**
	 * Returns the object for the specified locale.
	 * @param locale The requested locale.
	 * @return The localized object.
	 * @throws UnableToLocalizeException if an error occurs.
	 */
	T get(Locale locale);
	/**
	 * Returns the object for the default locale.
	 * @return The localized object.
	 * @throws UnableToLocalizeException if an error occurs.
	 */
	T get();
	/**
	 * Returns the object for the specified locale.
	 * @param locale The requested locale.
	 * @param locale Fallback value.
	 * @return The localized object or the fallback value if the localized object is {@code null} or an error occurs.
	 */
	T get(Locale locale, T fallback);
}
